@@ -2,11 +2,7 @@
 
 from datetime import datetime
 from decimal import Decimal
-from six import binary_type, integer_types, string_types
-
-
-def is_binary(val):
-    return isinstance(val, binary_type)
+from six import integer_types, string_types
 
 
 def is_bool(val):
@@ -37,8 +33,8 @@ def is_float(val):
     return isinstance(val, float)
 
 
-# def is_function(val):
-#     return callable(val)
+def is_function(val):
+    return callable(val)
 
 
 def is_integer(val):
@@ -46,8 +42,8 @@ def is_integer(val):
 
 
 def is_json_serializable(val):
-    json_types = (bool, dict, float, ) + integer_types + \
-        (list, tuple, set, ) + string_types
+    json_types = (type(None), bool, dict, float, list, tuple, ) + \
+                 integer_types + string_types
     return isinstance(val, json_types)
 
 
@@ -62,13 +58,18 @@ def is_list_or_tuple(val):
 def is_none(val):
     return val is None
 
-# def is_set(val):
-#     return isinstance(val, set)
+
+def is_not_none(val):
+    return val is not None
+
+
+def is_set(val):
+    return isinstance(val, set)
 
 
 def is_string(val):
     return isinstance(val, string_types)
 
 
-# def is_tuple(val):
-#     return isinstance(val, tuple)
+def is_tuple(val):
+    return isinstance(val, tuple)
